/******/ (() => { // webpackBootstrap
/******/ 	"use strict";
/******/ 	var __webpack_modules__ = ({

/***/ "./src/Transform.ts":
/*!**************************!*\
  !*** ./src/Transform.ts ***!
  \**************************/
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {



var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};
Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.transform = void 0;
const fs_1 = __webpack_require__(/*! fs */ "fs");
const path_1 = __importDefault(__webpack_require__(/*! path */ "path"));
const TypeUtils_1 = __webpack_require__(/*! upload-plugin-sdk/internal/TypeUtils */ "./src/internal/TypeUtils.ts");
const TransformationLocalFileManager_1 = __webpack_require__(/*! upload-plugin-sdk/internal/TransformationLocalFileManager */ "./src/internal/TransformationLocalFileManager.ts");
const fileManager = new TransformationLocalFileManager_1.TransformationLocalFileManager();
function transform({
  estimate,
  run
}) {
  return async invocation => {
    switch (invocation.type) {
      case "TransformationStep":
        return await runTransformStep(run, invocation);
      case "TransformationStepEstimation":
        {
          const defaultEstimate = {
            estimation: undefined
          };
          const result = estimate === undefined ? defaultEstimate : await runTransformStepEstimation(estimate, invocation);
          return result;
        }
      case "PluginHealthCheck":
        return {
          success: true
        };
      default:
        (0, TypeUtils_1.assertUnreachable)(invocation);
    }
  };
}
exports.transform = transform;
async function runTransformStep(handler, step) {
  const handlerWithEstimation = async (request
  // eslint-disable-next-line @typescript-eslint/no-invalid-void-type
  ) => await handler({
    ...request,
    estimationResult: step.estimationResult
  });
  const resultMaybe = await withTransformationParams("transformation", handlerWithEstimation, step);
  const result = resultMaybe !== undefined ? resultMaybe : {};
  return {
    async: result.async ?? Promise.resolve()
  };
}
async function runTransformStepEstimation(handler, step) {
  return await withTransformationParams("estimation", handler, step);
}
async function withTransformationParams(invocationType, handler, {
  paths,
  step,
  transformation,
  download
}) {
  const logs = [];
  /**
   * IMPORTANT!
   * - We want to keep S3 L2 costs down.
   * - We want to reduce latency as much as possible.
   * - As such, we don't log anything by default.
   * - Only the plugins must call the 'log' method (i.e. not the SDK), and even then, we try and avoid it:
   *   - Image Plugin never calls 'log'.
   *   - Archive Plugin never calls 'log'.
   */
  const log = msg => {
    const fullMsg = `${new Date().toISOString()} | ${step.plugin.packageName}@${step.plugin.packageVersion} | ${msg}`;
    console.log(fullMsg); // For local development.
    logs.push(fullMsg);
  };
  const resolve = fileManager.resolveFilePath(paths);
  const getMetadata = fileManager.getMetadata(paths);
  const setMetadata = fileManager.setMetadata(paths);
  try {
    const result = await handler({
      download,
      log,
      params: step.params,
      paths,
      resolve,
      getMetadata,
      setMetadata,
      step,
      transformation
    });
    return result;
  } finally {
    // Use an apex path -- "/log/" -- as this is less likely to collide with a file name required by a plugin,
    // since they will most likely be writing to named files, rather than apex files.
    const logUrl = "/log/";
    const logLocalFilePath = resolve(logUrl);
    const writeLog = async () => {
      if (logs.length === 0) {
        return; // Do not create an empty file.
      }

      await fs_1.promises.mkdir(path_1.default.dirname(logLocalFilePath), {
        recursive: true
      });
      await fs_1.promises.appendFile(logLocalFilePath, [...logs, ""].join("\n"));
    };
    await Promise.all([writeLog(), setMetadata(logUrl, {
      contentType: "text/plain"
    })]);
  }
}

/***/ }),

/***/ "./src/index.ts":
/*!**********************!*\
  !*** ./src/index.ts ***!
  \**********************/
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {



var __createBinding = this && this.__createBinding || (Object.create ? function (o, m, k, k2) {
  if (k2 === undefined) k2 = k;
  Object.defineProperty(o, k2, {
    enumerable: true,
    get: function () {
      return m[k];
    }
  });
} : function (o, m, k, k2) {
  if (k2 === undefined) k2 = k;
  o[k2] = m[k];
});
var __exportStar = this && this.__exportStar || function (m, exports) {
  for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", ({
  value: true
}));
/**
 * Facade Types
 */
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/LocalFileResolver */ "./src/types/transform/LocalFileResolver.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/FileMetadataGetter */ "./src/types/transform/FileMetadataGetter.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/FileMetadataSetter */ "./src/types/transform/FileMetadataSetter.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/DownloadRequest */ "./src/types/transform/DownloadRequest.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/DownloadResponse */ "./src/types/transform/DownloadResponse.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/FileDownloader */ "./src/types/transform/FileDownloader.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/Logger */ "./src/types/transform/Logger.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/EstimationHandler */ "./src/types/transform/EstimationHandler.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/EstimationHandlerParams */ "./src/types/transform/EstimationHandlerParams.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/TransformationHandler */ "./src/types/transform/TransformationHandler.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/TransformationHandlerParamsBase */ "./src/types/transform/TransformationHandlerParamsBase.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/transform/TransformationHandlerParams */ "./src/types/transform/TransformationHandlerParams.ts"), exports);
/**
 * Common Types
 */
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/TransformationDisplayableError */ "./src/types/TransformationDisplayableError.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/File */ "./src/types/File.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/FileTag */ "./src/types/FileTag.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/FileMetadata */ "./src/types/FileMetadata.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/ApexAndNamedFilePaths */ "./src/types/ApexAndNamedFilePaths.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/TransformationEstimation */ "./src/types/TransformationEstimation.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/FunctionInvocationFilePaths */ "./src/types/FunctionInvocationFilePaths.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/PluginPackage */ "./src/types/PluginPackage.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/PluginReference */ "./src/types/PluginReference.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/Transformation */ "./src/types/Transformation.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/TransformationCachePolicy */ "./src/types/TransformationCachePolicy.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/TransformationDefinition */ "./src/types/TransformationDefinition.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/TransformationDefinitionStep */ "./src/types/TransformationDefinitionStep.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/PluginInvocationResult */ "./src/types/PluginInvocationResult.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/PluginInvocation */ "./src/types/PluginInvocation.ts"), exports);
__exportStar(__webpack_require__(/*! upload-plugin-sdk/types/PluginDefaultExport */ "./src/types/PluginDefaultExport.ts"), exports);
/**
 * Internal API (used by upload-transformer)
 */
__exportStar(__webpack_require__(/*! upload-plugin-sdk/internal/TransformationLocalFileManager */ "./src/internal/TransformationLocalFileManager.ts"), exports);
/**
 * Public API
 */
__exportStar(__webpack_require__(/*! upload-plugin-sdk/Transform */ "./src/Transform.ts"), exports);

/***/ }),

/***/ "./src/internal/TransformationLocalFileManager.ts":
/*!********************************************************!*\
  !*** ./src/internal/TransformationLocalFileManager.ts ***!
  \********************************************************/
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {



var __importDefault = this && this.__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};
Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.TransformationLocalFileManager = void 0;
const fs_1 = __webpack_require__(/*! fs */ "fs");
const path_1 = __importDefault(__webpack_require__(/*! path */ "path"));
class TransformationLocalFileManager {
  constructor() {
    this.apexFileName = "index";
  }
  getMetadata(paths) {
    return async urlPath => {
      const metadataFilePath = this.resolveMetadataPath(paths, urlPath);
      if (!(await this.exists(metadataFilePath))) {
        return {};
      }
      return JSON.parse((await fs_1.promises.readFile(metadataFilePath)).toString());
    };
  }
  setMetadata(paths) {
    return async (urlPath, metadata) => {
      const metadataFilePath = this.resolveMetadataPath(paths, urlPath);
      const dir = path_1.default.dirname(metadataFilePath);
      await fs_1.promises.mkdir(dir, {
        recursive: true
      });
      await fs_1.promises.writeFile(metadataFilePath, JSON.stringify(metadata));
    };
  }
  resolveFilePath(paths) {
    return urlPath => this.resolvePath(paths.fileData, urlPath);
  }
  resolveMetadataPath(paths, urlPath) {
    return this.resolvePath(paths.fileMetadata, urlPath);
  }
  /**
   * Q: Why use two DIRs instead of a single DIR and replace every "/" with a "/_" to support apex files?
   *
   * A: While the single directory approach is cleaner, it creates more work for plugins that operate against entire
   *    directories. For example, the upload-compression-plugin, which needs to extract files to a directory. If we used
   *    the single directory abstraction (which relies on renaming files to contain a "_" prefix), such plugins would need
   *    to somehow inject a path translation middleware into the code that determines where to (for example) extract files.
   *
   * Sync with: upload-transformer/TransformationFunctionInvoker/resolveFilePath
   */
  resolvePath(root, urlPath) {
    if (!urlPath.startsWith("/")) {
      throw new Error("URL path must start with '/'.");
    }
    return urlPath.endsWith("/") ? this.resolveFilePathSafely(root.apexFileDir, `${urlPath.substring(1)}${this.apexFileName}`) : this.resolveFilePathSafely(root.namedFileDir, urlPath.substring(1));
  }
  resolveFilePathSafely(parentDir, childPath) {
    const resolvedPath = path_1.default.resolve(parentDir, childPath);
    const isParentDirOrChild = resolvedPath === parentDir || resolvedPath.startsWith(parentDir);
    if (!isParentDirOrChild) {
      throw new Error(`URL path contained a file traversal (which is prohibited): '${childPath}'`);
    }
    return resolvedPath;
  }
  async exists(folderOrFilePath) {
    try {
      await fs_1.promises.access(folderOrFilePath);
      return true;
    } catch {
      return false;
    }
  }
}
exports.TransformationLocalFileManager = TransformationLocalFileManager;

/***/ }),

/***/ "./src/internal/TypeUtils.ts":
/*!***********************************!*\
  !*** ./src/internal/TypeUtils.ts ***!
  \***********************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.assertUnreachable = void 0;
function assertUnreachable(x) {
  throw new Error(`Didn't expect to get here: ${JSON.stringify(x)}`);
}
exports.assertUnreachable = assertUnreachable;

/***/ }),

/***/ "./src/types/ApexAndNamedFilePaths.ts":
/*!********************************************!*\
  !*** ./src/types/ApexAndNamedFilePaths.ts ***!
  \********************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/File.ts":
/*!***************************!*\
  !*** ./src/types/File.ts ***!
  \***************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/FileMetadata.ts":
/*!***********************************!*\
  !*** ./src/types/FileMetadata.ts ***!
  \***********************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/FileTag.ts":
/*!******************************!*\
  !*** ./src/types/FileTag.ts ***!
  \******************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/FunctionInvocationFilePaths.ts":
/*!**************************************************!*\
  !*** ./src/types/FunctionInvocationFilePaths.ts ***!
  \**************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/PluginDefaultExport.ts":
/*!******************************************!*\
  !*** ./src/types/PluginDefaultExport.ts ***!
  \******************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/PluginInvocation.ts":
/*!***************************************!*\
  !*** ./src/types/PluginInvocation.ts ***!
  \***************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/PluginInvocationResult.ts":
/*!*********************************************!*\
  !*** ./src/types/PluginInvocationResult.ts ***!
  \*********************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/PluginPackage.ts":
/*!************************************!*\
  !*** ./src/types/PluginPackage.ts ***!
  \************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/PluginReference.ts":
/*!**************************************!*\
  !*** ./src/types/PluginReference.ts ***!
  \**************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/Transformation.ts":
/*!*************************************!*\
  !*** ./src/types/Transformation.ts ***!
  \*************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/TransformationCachePolicy.ts":
/*!************************************************!*\
  !*** ./src/types/TransformationCachePolicy.ts ***!
  \************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/TransformationDefinition.ts":
/*!***********************************************!*\
  !*** ./src/types/TransformationDefinition.ts ***!
  \***********************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/TransformationDefinitionStep.ts":
/*!***************************************************!*\
  !*** ./src/types/TransformationDefinitionStep.ts ***!
  \***************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/TransformationDisplayableError.ts":
/*!*****************************************************!*\
  !*** ./src/types/TransformationDisplayableError.ts ***!
  \*****************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.TransformationDisplayableError = void 0;
/**
 * NOTE: this error is only handled gracefully for plugins that are hosted as dedicated transformation APIs.
 */
class TransformationDisplayableError extends Error {
  /**
   * @param message Human readable message.
   * @param errorCode Machine readable error code.
   * @param isClientError False if a bug, true if client has any recourse.
   * @param httpStatusCode Status code, if the application supports custom status codes.
   *                   API supports custom status codes. Transform and Edge do not.
   */
  constructor(message, errorCode, isClientError,
  // The properties 'status' and 'statusCode' are somehow intercepted and defiled by Koa or TSOA (it sets them to 500
  // if undefined) -- so we intentionally choose a property name that doesn't get fiddled with by these frameworks.
  httpStatusCode, details) {
    super(message);
    this.errorCode = errorCode;
    this.isClientError = isClientError;
    this.httpStatusCode = httpStatusCode;
    this.details = details;
    Object.setPrototypeOf(this, TransformationDisplayableError.prototype);
    this.name = "TransformationDisplayableError";
  }
}
exports.TransformationDisplayableError = TransformationDisplayableError;

/***/ }),

/***/ "./src/types/TransformationEstimation.ts":
/*!***********************************************!*\
  !*** ./src/types/TransformationEstimation.ts ***!
  \***********************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/DownloadRequest.ts":
/*!************************************************!*\
  !*** ./src/types/transform/DownloadRequest.ts ***!
  \************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/DownloadResponse.ts":
/*!*************************************************!*\
  !*** ./src/types/transform/DownloadResponse.ts ***!
  \*************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/EstimationHandler.ts":
/*!**************************************************!*\
  !*** ./src/types/transform/EstimationHandler.ts ***!
  \**************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/EstimationHandlerParams.ts":
/*!********************************************************!*\
  !*** ./src/types/transform/EstimationHandlerParams.ts ***!
  \********************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/FileDownloader.ts":
/*!***********************************************!*\
  !*** ./src/types/transform/FileDownloader.ts ***!
  \***********************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/FileMetadataGetter.ts":
/*!***************************************************!*\
  !*** ./src/types/transform/FileMetadataGetter.ts ***!
  \***************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/FileMetadataSetter.ts":
/*!***************************************************!*\
  !*** ./src/types/transform/FileMetadataSetter.ts ***!
  \***************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/LocalFileResolver.ts":
/*!**************************************************!*\
  !*** ./src/types/transform/LocalFileResolver.ts ***!
  \**************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/Logger.ts":
/*!***************************************!*\
  !*** ./src/types/transform/Logger.ts ***!
  \***************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/TransformationHandler.ts":
/*!******************************************************!*\
  !*** ./src/types/transform/TransformationHandler.ts ***!
  \******************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/TransformationHandlerParams.ts":
/*!************************************************************!*\
  !*** ./src/types/transform/TransformationHandlerParams.ts ***!
  \************************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "./src/types/transform/TransformationHandlerParamsBase.ts":
/*!****************************************************************!*\
  !*** ./src/types/transform/TransformationHandlerParamsBase.ts ***!
  \****************************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));

/***/ }),

/***/ "fs":
/*!*********************!*\
  !*** external "fs" ***!
  \*********************/
/***/ ((module) => {

module.exports = require("fs");

/***/ }),

/***/ "path":
/*!***********************!*\
  !*** external "path" ***!
  \***********************/
/***/ ((module) => {

module.exports = require("path");

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	
/******/ 	// startup
/******/ 	// Load entry module and return exports
/******/ 	// This entry module is referenced by other modules so it can't be inlined
/******/ 	var __webpack_exports__ = __webpack_require__("./src/index.ts");
/******/ 	module.exports = __webpack_exports__;
/******/ 	
/******/ })()
;